@@ -129,6 +129,11 @@ def init_spark(
     Returns:
 
     """
+    jars = []
+    if connect_psql:
+        jars+=["org.postgresql:postgresql:42.5.2"]
+    if minio_endpoint is not None:
+        jars += ["org.apache.hadoop:hadoop-aws:3.3.2", "com.amazonaws:aws-java-sdk-bundle:1.12.405"]
 
     spark_conf = (
         SparkConf()
@@ -138,9 +143,7 @@ def init_spark(
         .set("spark.ui.port", "4043")
         .set(
             "spark.jars.packages",
-            "org.postgresql:postgresql:42.5.2,"
-            "org.apache.hadoop:hadoop-aws:3.3.2,"
-            "com.amazonaws:aws-java-sdk-bundle:1.12.405"
+            ",".join(jars)
         )  # if you set park.jars.packages more than once, only the last one will be used.
         .set("spark.hadoop.fs.s3a.impl", "org.apache.hadoop.fs.s3a.S3AFileSystem")
         .set("spark.hadoop.fs.s3a.path.style.access ", "true")
@@ -148,9 +151,6 @@ def init_spark(
     )
     spark = (
         SparkSession.builder.config(conf=spark_conf).getOrCreate()
-        # .config("spark.jars", "/home/zhan/Projects/longalpha_utils/postgresql-42.5.2.jar")
-        # .config("spark.driver.extraClassPath", "/home/zhan/Projects/longalpha_utils/postgresql-42.5.2.jar")
-        # .config("spark.executor.extraClassPath", "/home/zhan/Projects/longalpha_utils/postgresql-42.5.2.jar")
 
     )
 
